@@ -10,7 +10,7 @@ Environment
 """
 
 #
-# Copyright (c) 2001 - 2017 The SCons Foundation
+# Copyright (c) 2001 - 2018 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -31,7 +31,7 @@ Environment
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "src/engine/SCons/Environment.py rel_3.0.0:4395:8972f6a2f699 2017/09/18 13:28:16 bdbaddog"
+__revision__ = "src/engine/SCons/Environment.py 8bcbf788a94dd8067ab0e5bccf1c0f0e9bc62a76 2019-01-01 00:03:08 bdbaddog"
 
 
 import copy
@@ -150,7 +150,7 @@ def _set_BUILDERS(env, key, value):
         for k in list(bd.keys()):
             del bd[k]
     except KeyError:
-        bd = BuilderDict(kwbd, env)
+        bd = BuilderDict(bd, env)
         env._dict[key] = bd
     for k, v in value.items():
         if not SCons.Builder.is_a_Builder(v):
@@ -2258,7 +2258,7 @@ class Base(SubstitutionEnvironment):
             while (node != node.srcnode()):
               node = node.srcnode()
             return node
-        sources = list(map( final_source, sources ));
+        sources = list(map(final_source, sources))
         # remove duplicates
         return list(set(sources))
 
