@@ -6,7 +6,7 @@ Nodes.
 """
 
 #
-# Copyright (c) 2001 - 2017 The SCons Foundation
+# Copyright (c) 2001 - 2018 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -28,7 +28,7 @@ Nodes.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 from __future__ import print_function
 
-__revision__ = "src/engine/SCons/Executor.py rel_3.0.0:4395:8972f6a2f699 2017/09/18 13:28:16 bdbaddog"
+__revision__ = "src/engine/SCons/Executor.py 8bcbf788a94dd8067ab0e5bccf1c0f0e9bc62a76 2019-01-01 00:03:08 bdbaddog"
 
 import collections
 
@@ -450,6 +450,8 @@ class Executor(object, with_metaclass(NoSlotsPyPy)):
         """Fetch the signature contents.  This is the main reason this
         class exists, so we can compute this once and cache it regardless
         of how many target or source Nodes there are.
+
+        Returns bytes
         """
         try:
             return self._memo['get_contents']
