@@ -3,7 +3,7 @@
 Used by several tools of `gettext` toolset.
 """
 
-# Copyright (c) 2001 - 2017 The SCons Foundation
+# Copyright (c) 2001 - 2018 The SCons Foundation
 # 
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -24,7 +24,7 @@ Used by several tools of `gettext` toolset.
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "src/engine/SCons/Tool/GettextCommon.py rel_3.0.0:4395:8972f6a2f699 2017/09/18 13:28:16 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/GettextCommon.py 8bcbf788a94dd8067ab0e5bccf1c0f0e9bc62a76 2019-01-01 00:03:08 bdbaddog"
 
 import SCons.Warnings
 import re
@@ -390,7 +390,7 @@ def _detect_xgettext(env):
     """ Detects *xgettext(1)* binary """
     if 'XGETTEXT' in env:
         return env['XGETTEXT']
-    xgettext = env.Detect('xgettext');
+    xgettext = env.Detect('xgettext')
     if xgettext:
         return xgettext
     raise SCons.Errors.StopError(XgettextNotFound, "Could not detect xgettext")
@@ -409,7 +409,7 @@ def _detect_msginit(env):
     """ Detects *msginit(1)* program. """
     if 'MSGINIT' in env:
         return env['MSGINIT']
-    msginit = env.Detect('msginit');
+    msginit = env.Detect('msginit')
     if msginit:
         return msginit
     raise SCons.Errors.StopError(MsginitNotFound, "Could not detect msginit")
@@ -428,7 +428,7 @@ def _detect_msgmerge(env):
     """ Detects *msgmerge(1)* program. """
     if 'MSGMERGE' in env:
         return env['MSGMERGE']
-    msgmerge = env.Detect('msgmerge');
+    msgmerge = env.Detect('msgmerge')
     if msgmerge:
         return msgmerge
     raise SCons.Errors.StopError(MsgmergeNotFound, "Could not detect msgmerge")
@@ -447,7 +447,7 @@ def _detect_msgfmt(env):
     """ Detects *msgmfmt(1)* program. """
     if 'MSGFMT' in env:
         return env['MSGFMT']
-    msgfmt = env.Detect('msgfmt');
+    msgfmt = env.Detect('msgfmt')
     if msgfmt:
         return msgfmt
     raise SCons.Errors.StopError(MsgfmtNotFound, "Could not detect msgfmt")
