@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2001 - 2017 The SCons Foundation
+# Copyright (c) 2001 - 2018 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -30,7 +30,7 @@
 #   * test on 64 bits XP +  VS 2005 (and VS 6 if possible)
 #   * SDK
 #   * Assembly
-__revision__ = "src/engine/SCons/Tool/MSCommon/vc.py rel_3.0.0:4395:8972f6a2f699 2017/09/18 13:28:16 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/MSCommon/vc.py 8bcbf788a94dd8067ab0e5bccf1c0f0e9bc62a76 2019-01-01 00:03:08 bdbaddog"
 
 __doc__ = """Module for Visual C/C++ detection and configuration.
 """
@@ -43,6 +43,7 @@ import platform
 from string import digits as string_digits
 
 import SCons.Warnings
+from SCons.Tool import find_program_path
 
 from . import common
 
@@ -357,9 +358,15 @@ def get_installed_vcs():
     for ver in _VCVER:
         debug('trying to find VC %s' % ver)
         try:
-            if find_vc_pdir(ver):
+            VC_DIR = find_vc_pdir(ver)
+            if VC_DIR:
                 debug('found VC %s' % ver)
-                installed_versions.append(ver)
+                # check to see if the x86 or 64 bit compiler is in the bin dir
+                if (os.path.exists(os.path.join(VC_DIR, r'bin\cl.exe'))
+                    or os.path.exists(os.path.join(VC_DIR, r'bin\amd64\cl.exe'))):
+                    installed_versions.append(ver)
+                else:
+                    debug('find_vc_pdir no cl.exe found %s' % ver)
             else:
                 debug('find_vc_pdir return None for ver %s' % ver)
         except VisualCException as e:
@@ -565,6 +572,12 @@ def msvc_setup_env(env):
     for k, v in d.items():
         debug('vc.py:msvc_setup_env() env:%s -> %s'%(k,v))
         env.PrependENVPath(k, v, delete_existing=True)
+    
+    # final check to issue a warning if the compiler is not present
+    msvc_cl = find_program_path(env, 'cl')
+    if not msvc_cl:
+        SCons.Warnings.warn(SCons.Warnings.VisualCMissingWarning, 
+            "Could not find MSVC compiler 'cl.exe', it may need to be installed separately with Visual Studio")
 
 def msvc_exists(version=None):
     vcs = cached_get_installed_vcs()
