@@ -9,7 +9,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2017 The SCons Foundation
+# Copyright (c) 2001 - 2018 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -31,10 +31,11 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/mingw.py 74b2c53bc42290e911b334a6b44f187da698a668 2017/11/14 13:16:53 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/mingw.py 8bcbf788a94dd8067ab0e5bccf1c0f0e9bc62a76 2019-01-01 00:03:08 bdbaddog"
 
 import os
 import os.path
+import glob
 
 import SCons.Action
 import SCons.Builder
@@ -42,26 +43,14 @@ import SCons.Defaults
 import SCons.Tool
 import SCons.Util
 
-# This is what we search for to find mingw:
-key_program = 'mingw32-gcc'
 
-def find(env):
-    # First search in the SCons path
-    path=env.WhereIs(key_program)
-    if (path):
-        return path
-    # then the OS path:
-    path=SCons.Util.WhereIs(key_program)
-    if (path):
-        return path
-
-    # If that doesn't work try default location for mingw
-    save_path=env['ENV']['PATH']
-    env.AppendENVPath('PATH',r'c:\MinGW\bin')
-    path =env.WhereIs(key_program)
-    if not path:
-        env['ENV']['PATH']=save_path
-    return path
+mingw_paths = [
+    r'c:\MinGW\bin',
+    r'C:\cygwin64\bin',
+    r'C:\msys64',
+    r'C:\cygwin\bin',
+    r'C:\msys',
+]
 
 def shlib_generator(target, source, env, for_signature):
     cmd = SCons.Util.CLVar(['$SHLINK', '$SHLINKFLAGS']) 
@@ -126,12 +115,33 @@ res_builder = SCons.Builder.Builder(action=res_action, suffix='.o',
                                     source_scanner=SCons.Tool.SourceFileScanner)
 SCons.Tool.SourceFileScanner.add_scanner('.rc', SCons.Defaults.CScan)
 
+# This is what we search for to find mingw:
+# key_program = 'mingw32-gcc'
+key_program = 'mingw32-make'
+
+
+
+def find_version_specific_mingw_paths():
+    """
+    One example of default mingw install paths is:
+    C:\mingw-w64\x86_64-6.3.0-posix-seh-rt_v5-rev2\mingw64\bin
+
+    Use glob'ing to find such and add to mingw_paths
+    """
+    new_paths = glob.glob(r"C:\mingw-w64\*\mingw64\bin")
+    
+    return new_paths
+
+
 def generate(env):
-    mingw = find(env)
+    global mingw_paths
+    # Check for reasoanble mingw default paths
+    mingw_paths +=find_version_specific_mingw_paths() 
+
+    mingw = SCons.Tool.find_program_path(env, key_program, default_paths=mingw_paths)
     if mingw:
-        dir = os.path.dirname(mingw)
-        env.PrependENVPath('PATH', dir )
-        
+        mingw_bin_dir = os.path.dirname(mingw)
+        env.AppendENVPath('PATH', mingw_bin_dir)
 
     # Most of mingw is the same as gcc and friends...
     gnu_tools = ['gcc', 'g++', 'gnulink', 'ar', 'gas', 'gfortran', 'm4']
@@ -173,7 +183,12 @@ def generate(env):
     env['PROGSUFFIX'] = '.exe'
 
 def exists(env):
-    return find(env)
+    mingw = SCons.Tool.find_program_path(env, key_program, default_paths=mingw_paths)
+    if mingw:
+        mingw_bin_dir = os.path.dirname(mingw)
+        env.AppendENVPath('PATH', mingw_bin_dir)
+
+    return mingw
 
 # Local Variables:
 # tab-width:4
