@@ -4,7 +4,7 @@ The msi packager.
 """
 
 #
-# Copyright (c) 2001 - 2017 The SCons Foundation
+# Copyright (c) 2001 - 2018 The SCons Foundation
 # 
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -25,7 +25,7 @@ The msi packager.
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "src/engine/SCons/Tool/packaging/msi.py rel_3.0.0:4395:8972f6a2f699 2017/09/18 13:28:16 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/packaging/msi.py 8bcbf788a94dd8067ab0e5bccf1c0f0e9bc62a76 2019-01-01 00:03:08 bdbaddog"
 
 import os
 import SCons
@@ -63,8 +63,8 @@ def convert_to_id(s, id_set):
     """
     charset = 'ABCDEFGHIJKLMNOPQRSTUVWXYabcdefghijklmnopqrstuvwxyz0123456789_.'
     if s[0] in '0123456789.':
-        s += '_'+s
-    id = [c for c in s if c in charset]
+        s = '_' + s
+    id = ''.join([c for c in s if c in charset])
 
     # did we already generate an id for this file?
     try:
@@ -108,14 +108,13 @@ def gen_dos_short_file_name(file, filename_set):
 
     # strip forbidden characters.
     forbidden = '."/[]:;=, '
-    fname = [c for c in fname if c not in forbidden]
+    fname = ''.join([c for c in fname if c not in forbidden])
 
     # check if we already generated a filename with the same number:
     # thisis1.txt, thisis2.txt etc.
     duplicate, num = not None, 1
     while duplicate:
-        shortname = "%s%s" % (fname[:8-len(str(num))].upper(),\
-                              str(num))
+        shortname = "%s%s" % (fname[:8-len(str(num))].upper(), str(num))
         if len(ext) >= 2:
             shortname = "%s%s" % (shortname, ext[:4].upper())
 
@@ -301,7 +300,7 @@ def build_wxsfile_file_section(root, files, NAME, VERSION, VENDOR, filename_set,
                                if c.nodeName == 'Directory'
                                and c.attributes['LongName'].value == escape(d)] 
 
-            if already_created != []:
+            if already_created:
                 Directory = already_created[0]
                 dir_parts.remove(d)
                 upper_dir += d
